#
# spec file for package libuev
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2018, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 3
Name:           libuev
Version:        2.4.1
Release:        2.5
Summary:        Event loop library
License:        MIT
Group:          Development/Languages/C and C++
URL:            https://github.com/troglobit/libuev/
Source:         https://github.com/troglobit/libuev/releases/download/v%{version}/%{name}-%{version}.tar.xz
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig

%description
libuEv is an event loop in the style of libevent, libev and the Xt(3)
event loop. It has a small feature set.

libuEv is built on top of the Linux APIs epoll, timerfd and signalfd.
Note however, a certain amount of care is needed when dealing with
APIs that employ signalfd.

%package -n libuev%{sover}
Summary:        Event loop library
Group:          System/Libraries

%description -n libuev%{sover}
libuEv is an event loop in the style of libevent, libev and the Xt(3)
event loop. It has a small feature set.

libuEv is built on top of the Linux APIs epoll, timerfd and signalfd.
Note however, a certain amount of care is needed when dealing with
APIs that employ signalfd.

%package devel
Summary:        Header files for libuEv
Group:          Development/Libraries/C and C++
Requires:       libuev%{sover} = %{version}

%description devel
Development and header files for libuEv.

%prep
%autosetup -p1

%build
%configure \
  --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
rm -r %{buildroot}%{_datadir}/doc

%check
%make_build check

%post   -n libuev%{sover} -p /sbin/ldconfig
%postun -n libuev%{sover} -p /sbin/ldconfig

%files -n libuev%{sover}
%doc AUTHORS ChangeLog.md README.md
%license LICENSE
%{_libdir}/libuev.so.%{sover}*

%files devel
%license LICENSE doc/API.md
%{_includedir}/uev
%{_libdir}/libuev.so
%{_libdir}/pkgconfig/libuev.pc

%changelog
* Fri Jan  5 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.4.1:
  * Update README with list of moden Linux APIs used
  * Fix #27: possible buffer overrun in uev_run()
    bsc#1218749 CVE-2022-48620
* Sat Oct  9 2021 Andreas Stieger <andreas.stieger@gmx.de>
- libuev 2.4.0:
  * major ABI bump:
    Add struct signalfd_siginfo to uev_t, valid for signal watchers
    Now more metadata is available to signal callbacks
  * built for 64 bit time_t, requiring users to use the following:
    CPPFLAGS += -D_TIME_BITS=64 -D_FILE_OFFSET_BITS=64
  * documentation updates
- run tests during build
- drop 0001-Fix-25-glibc-2.33-requires-_FILE_OFFSET_BITS-64-with.patch
* Sun Sep 19 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add glibc >= 2.33 build fix:
  * 0001-Fix-25-glibc-2.33-requires-_FILE_OFFSET_BITS-64-with.patch
* Sun Feb 14 2021 Andreas Stieger <andreas.stieger@gmx.de>
- libuev 2.3.2:
  * fixes for other distributions only
- switch to bootstrapped upstream tarball
* Tue Feb 25 2020 Michael Vetter <mvetter@suse.com>
- Update to 2.3.1:
  * Use separate aux/ dir for auxilliary files and check for install
* Mon Apr  8 2019 mvetter@suse.com
- Update to 2.3.0:
  * Support for Linux eventfd, uev_event_*() see API.md for details
* Mon Oct  8 2018 mvetter@suse.com
- Update to 2.2.0:
  Note:
  * You now have to explicitly include sys/queue.h, or provide
    a local version of queue.h, if your application depends on it.
  Changes:
  * Replaced BSD queue.h doubly-linked lst API with own
    implementation. Making libuEv stand-alone, no longer imposing
  any particular version of queue.h on the user
  * Enforce -std=gnu11 to unlock typeof() in older GCC versions
  * Code cleanup
  Fixes:
  * Fix missing header deps. in Makefile.am, library did not rebuild
    properly if any of the local header files were changed
* Fri Sep  7 2018 mvetter@suse.com
- Update to 2.1.3:
  Changes:
  * Update joystick example, use first device, /dev/input/js0
  * Minor refactor of uev_exit(), use _SAFE macros to traverse
    list of watchers instead of while()
  * New API test to verify that uev_exit() terminates properly
  * Make uev_signal_stop() idempotent
  Fixes:
  * Let uev_timer_stop() call close() on the timerfd directly,
    do not call uev_timer_set() since that may cause
    lockups or hangs
* Sun Jul 29 2018 jengelh@inai.de
- Ensure neutrality of descriptions.
* Mon Jun 18 2018 mardnh@gmx.de
- Initial package, version 2.1.2
